summaryrefslogtreecommitdiffstats
path: root/kpat/freecell-solver/intrface.c
diff options
context:
space:
mode:
Diffstat (limited to 'kpat/freecell-solver/intrface.c')
-rw-r--r--kpat/freecell-solver/intrface.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/kpat/freecell-solver/intrface.c b/kpat/freecell-solver/intrface.c
index 6551652b..e70e8fca 100644
--- a/kpat/freecell-solver/intrface.c
+++ b/kpat/freecell-solver/intrface.c
@@ -214,7 +214,7 @@ static freecell_solver_soft_thread_t * alloc_soft_thread(
freecell_solver_initialize_bfs_queue(soft_thread);
/* Initialize the priotity queue of the A* scan */
- soft_thread->a_star_pqueue = malloc(sizeof(PQUEUE));
+ soft_thread->a_star_pqueue = malloc(sizeof(PTQUEUE));
freecell_solver_PQueueInitialise(
soft_thread->a_star_pqueue,
1024
@@ -795,8 +795,8 @@ static void trace_solution(
s1 = instance->final_state;
- /* Retrace the step from the current state to its parents */
- while (s1->parent != NULL)
+ /* Retrace the step from the current state to its tqparents */
+ while (s1->tqparent != NULL)
{
/* Mark the state as part of the non-optimized solution */
s1->visited |= FCS_VISITED_IN_SOLUTION_PATH;
@@ -811,8 +811,8 @@ static void trace_solution(
}
/* Duplicate the state to a freshly malloced memory */
- /* Move to the parent state */
- s1 = s1->parent;
+ /* Move to the tqparent state */
+ s1 = s1->tqparent;
}
/* There's one more state than there are move stacks */
s1->visited |= FCS_VISITED_IN_SOLUTION_PATH;
@@ -915,7 +915,7 @@ int freecell_solver_solve_instance(
state_copy_ptr->depth = 0;
state_copy_ptr->moves_to_parent = NULL;
state_copy_ptr->visited = 0;
- state_copy_ptr->parent = NULL;
+ state_copy_ptr->tqparent = NULL;
memset(&(state_copy_ptr->scan_visited), '\0', sizeof(state_copy_ptr->scan_visited));
instance->state_copy_ptr = state_copy_ptr;